:tocdepth: 2

.. _authors:

Authors
=======

Aqtinstall is written and maintained by Hiroshi Miura <miurahr@linux.com>

Original qli-installer is written by Linus Jahn

Significant contributions for improvements of version 2.0 by David Dalcino

All contributors, listed alphabetically, are:

* Andrei Yankovich (tools ifw installation)
* Aurélien Gâteau (patching to qmake)
* Benjamin O (Github Actions and more)
* David Dalcino (CI automations, List commands, improve tests, documents and fix patching to qmake)
* Felix Barz (Android, Explicit extra module installation)
* Gamso (improve parsing of update.xml)
* Julien Marrec (mypy, type hints)
* Kyle Altendorf (7z binary path search)
* lightmare (Documents)
* Martin Delille (Documents)
* Mizux Seihax (Qt versions)
* Mozi (CI/workflow improvement)
* Nelson Chen (CI tests)
* @nikitalita (Binary distribution)
* @pylipp (Documents)
* Sztergbaum Roman (Version database)
* Thomas Grainger (CLI entry point)
* @tsteven4 (fix patching to qmake, pkgconfig and libtool)
* Vadim Peretokin (Version database)
* Vladyslav Hnatiuk (Version database)
* @ypnos (Documents)

and many other participants and contributors.
If you find a missing name to record, please feel free to tell me.